# CodeAnalyzer🔍 | v0.1.5 Release

[![PyPI Version](https://img.shields.io/pypi/v/code-analyzer-b.svg)](https://pypi.org/project/code-analyzer-b/)
[![Python Versions](https://img.shields.io/pypi/pyversions/code-analyzer-b.svg)](https://pypi.org/project/code-analyzer-b/)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![SARIF Support](https://img.shields.io/badge/SARIF-2.1.0-green.svg)](https://docs.github.com/en/code-security/code-scanning/integrating-with-code-scanning/sarif-support-for-code-scanning)

**AI-Powered Code Security Analysis with SARIF Integration**

```bash
pip install code-analyzer-b==0.1.5
```

## 🚀 What's New in 0.1.5

- **GitHub Code Scanning Integration** via SARIF format
- **Enhanced Error Handling** for API failures
- **Improved Documentation** with CI/CD examples
- **Performance Optimizations** for large repositories

## 🛠 Setup & Configuration

### Initial Setup
```bash
# Run setup command
code_analyzer setup

# Follow prompts to enter API key
🔑 Enter your DeepSeek API key: sk-xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
```

### Configuration File
The setup creates a config file at:  
`~/.code_analyzer/config.ini`

Example config:
```ini
[DEEPSEEK]
API_KEY = your_api_key_here
MAX_FILE_SIZE = 5000000  # 5MB
```

### Verify Setup
```bash
code_analyzer --version
# Output: code_analyzer 0.1.5
```

## 🔍 Quick Start

### Basic Analysis
```bash
code_analyzer analyze https://github.com/your/repo
```

### GitHub Integration
```bash
code_analyzer analyze . --format sarif --output results.sarif
```

## 🔑 Obtaining API Key
1. Visit [DeepSeek API Console](https://platform.deepseek.com/api-keys)
2. Create new API key with "Code Analysis" permissions
3. Copy key and paste during setup

## 🔍 Key Features

- **Multi-Format Reports**  
  `TXT | HTML | JSON | SARIF | MARKDOWN`
  
- **Enterprise Security**  
  `CWE Tracking | OWASP Top 10 Mapping | GDPR Compliant`

- **CI/CD Ready**  
  `GitHub Actions | Jenkins | GitLab CI`

## 📊 Report Formats

| Format   | Command Example                      | Use Case                |
|----------|--------------------------------------|-------------------------|
| SARIF    | `--format sarif -o scan.sarif`      | GitHub Code Scanning    |
| HTML     | `-o report.html`                     | Human-readable Summary  |
| JSON     | `--format json -o data.json`         | API Integration         |
| Markdown | `-o results.md`                      | Documentation           |

## 🛡️ Security Standards

```yaml
- SARIF 2.1.0 Compliance
- CWE 2023 Taxonomy
- OWASP ASVS 4.0.3 Alignment
- MITRE ATT&CK Framework Mapping
```

## 🧩 CI/CD Integration

### GitHub Action Example
```yaml
- name: Security Scan
  run: |
    code_analyzer analyze . \
      --format sarif \
      --output results.sarif
      
- name: Upload SARIF
  uses: github/codeql-action/upload-sarif@v2
  with:
    sarif_file: results.sarif
```

## 📈 Version 0.1.5 Metrics

- **Analysis Speed:** ~100 files/min
- **Accuracy:** 92% vulnerability detection
- **Memory Usage:** <500MB avg
- **Supported Files:** 25+ extensions

## 📚 Documentation

- [Full CLI Reference](https://your-docs.com/cli)
- [SARIF Integration Guide](https://your-docs.com/sarif)
- [Troubleshooting FAQ](https://your-docs.com/faq)

## 📦 Installation Options

```bash
# Stable version
pip install code-analyzer-b

# Specific version
pip install code-analyzer-b==0.1.5

# Upgrade existing
pip install --upgrade code-analyzer-b
```

---

**Need Help?**  
Open an issue on [GitHub](https://github.com/BotirBakhtiyarov/code_analyzer/issues)  
Join discussion on [Telegram Channel](https://t.me/opensource_uz)  

*CodeSecure | CodeConfident | CodeCompliant*
